# Wluper Plugin


# Getting Started

1. Add the package in `dev_dependencies`.
```
dev_dependencies:
  wluper_plugin_flutter: ^1.0.0
```

2. Import the plugin in `main.dart` or where you need.
```dart
import 'package:wluper_plugin_flutter/wluper_plugin_flutter.dart';
import 'package:wluper_plugin_flutter/wluper_plugin_interface.dart';
```

3. Implement `WluperPluginInterface` protocol in the class where you want manipulate the parsed tree.
```dart
class _MyAppState extends State<MyApp> implements WluperPluginInterface {
    ...
```

4. Override the methods of the `WluperPluginInterface` to handle Errors, live text and end of speech event.
```dart
  @override
  void wluperOnError(String error){
 		// implement here your code
  }

  @override
  void wluperOnLiveText(String text){
		// implement here your code
  }

  @override
  void wluperEndOfSpeech(){
		// implement here your code
  }
```

3. Declare `WluperPluginFlutter` object.
```dart
class _MyAppState extends State<MyApp> implements WluperPluginInterface {
    ...
    WluperPluginFlutter wluperSDK = WluperPluginFlutter();
    ...
```

6. Initialise the SDK with the `api_key` and the `WluperPluginInterface` listener.
```dart
Future<void> initPlatformState() async {
    ...
      wluperSDK.init(_api_key, this).then((result) => /*implement here your code*/ );
    ...
```

7. Wrap plugin methods `wluperSDK.startListening()`, `wluperSDK.understand()` and `wluperSDK.understand()`.

``` dart
class _MyAppState extends State<MyApp> implements WluperPluginInterface {
    ...
      
  void startListening(){
    wluperSDK.startListening().then((result) => /*implement here your code*/);
  }

  void understand(text){
    wluperSDK.understand(text).then((result) => /*implement here your code*/);
  }

  void cancelListening(){
  	wluperSDK.cancelListening().then((result) => setState(() => /*implement here your code*/);
  }
  
    ...
```

8. Invoke the methods `startListening()`,  `understand(text)`  and `cancelListening()` from UI. While you speak, the live text is received by the listener `wluperOnLiveText` . The end of speech is detected automatically by the SDK and it is notified in the `wluperEndOfSpeech` callback  (see point 4).
```dart
class _MyAppState extends State<MyApp> implements WluperPluginInterface{
  String _status = 'Unknown';
  String _tree = "";
  String _error = "";
  String _plain_text ="";
...
  void cleanUI(){
      setState(() {
        _status = "";
        _error= "";
        _tree = "";
        _plain_text = "";
      });
  }
...
	children: <Widget>[
    Text('SDK STATUS', style: TextStyle(fontWeight: FontWeight.bold)),
    Text(_status),
    Row(
      children: <Widget>[
        TextButton(style: TextButton.styleFrom( textStyle: const TextStyle(fontSize: 20)),
                   onPressed: () { cleanUI(); startListening(); },
                   child: const Text('Listen')),
        TextButton( style: TextButton.styleFrom(textStyle: const TextStyle(fontSize: 20)),
                   onPressed: () { cancelListening();},
                   child: const Text('Cancel'))
      ],
    ),
    Text('ASR OUTPUT', style: TextStyle(fontWeight: FontWeight.bold)),
    TextField( controller: textController, 
              maxLines: 3,
              decoration: const InputDecoration( border: OutlineInputBorder(),
                                  hintText: 'Enter a sentence to understand')),
    TextButton( style: TextButton.styleFrom( textStyle: const TextStyle(fontSize: 20)),
               onPressed: () { understand(textController.text); },
               child: const Text('Understand')),
    Text('BODY RESPONSE', style: TextStyle(fontWeight: FontWeight.bold)),
    Text(_tree),
    Text('ERROR', style: TextStyle(fontWeight: FontWeight.bold)),
    Text(_error),
  ])
...
```

9. Permissions

_Android_ 
Add below permission to the `AndroidManifest.xml`
```xml
<uses-permission android:name="android.permission.RECORD_AUDIO" />
```
_iOS_
Add below permissions to `info.plist`
```xml
<key>NSMicrophoneUsageDescription</key>
<string>Audio is recorded and transcribed.</string>
<key>NSSpeechRecognitionUsageDescription</key>
<string>We need to record your voice.</string>
```