
import 'dart:async';
import 'package:flutter/services.dart';
import 'package:platform_device_id/platform_device_id.dart';
import 'package:device_info/device_info.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'dart:io' show Platform;
import 'device_info.dart';

class WluperPluginFlutter {
  static const MethodChannel _channel = const MethodChannel('wluper_plugin_flutter');
  static final DeviceInfoPlugin deviceInfoPlugin = DeviceInfoPlugin();
  var _listenerClass;

    WluperPluginFlutter() {
    _channel.setMethodCallHandler(invokedMethods);

  }


  Future<String> init(x_api_key, listenerClass) async {
    try{
        await _channel.invokeMethod("WluperSDK", {"x_api_key":x_api_key});
            PackageInfo packageInfo = await PackageInfo.fromPlatform();
            this._listenerClass = listenerClass;

            var device = DeviceInfo();
            device.sdk_version = packageInfo.version;
            device.device_id = (await PlatformDeviceId.getDeviceId)!;

            if (Platform.isAndroid) {
              device.model = (await deviceInfoPlugin.androidInfo).model;
              device.os_version = (await deviceInfoPlugin.androidInfo).version.release;
              device.os_name = "Android";
            } else if (Platform.isIOS) {
              device.model = (await deviceInfoPlugin.iosInfo).utsname.machine;
              device.os_version = (await deviceInfoPlugin.iosInfo).systemVersion;
              device.os_name = "iOS";
            }
            var argument = device.toJson();
            await _channel.invokeMethod("WluperDeviceInfo", argument);
            return "SDK initialised";
    } catch(error) {
      return "SDK "+ error.toString();
    }
  }

  Future<String> startListening() async {
    return await _channel.invokeMethod("startListening");
  }

  Future<int> cancelListening() async {
    return await _channel.invokeMethod("cancelListening");
  }

  Future<Object> understand(plain_text) async {
    return await _channel.invokeMethod("understand",{"plain_text":plain_text});
  }

  Future<dynamic> invokedMethods(MethodCall methodCall) async {
    switch (methodCall.method) {
        case "WluperError":
          this._listenerClass.wluperOnError(methodCall.arguments.toString());
          return methodCall.arguments;
        case "WluperLiveText":
          this._listenerClass.wluperOnLiveText(methodCall.arguments);
          return methodCall.arguments;
        case "WluperEndOfSpeech":
          this._listenerClass.wluperEndOfSpeech();
          return methodCall.arguments;
      }
  }

}